;; Generated package description from xeft.el  -*- no-byte-compile: t -*-
(define-package "xeft" "3.3" "Deft feat. Xapian" '((emacs "26.0")) :commit "ea4fa859c1129243b15f259a10e67ea274c5ef63" :authors '(("Yuan Fu" . "casouri@gmail.com")) :maintainer '("Yuan Fu" . "casouri@gmail.com") :keywords '("applications" "note" "searching") :url "https://sr.ht/~casouri/xeft")
